==> fastsms_0.5-4.tar.gz: fastsms-0.5/src/layoutmanager.cpp <==
/****************************************************************************
**
** Copyright (C) 2010  Aimone Davide realsportcars@hotmail.com
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
**
****************************************************************************/

#include "layoutmanager.h"
#include "ui_layoutmanager.h"
#include "keyboardmanager.h"


LayoutManager::LayoutManager(QWidget *parent) :
        QWidget(parent),
        ui(new Ui::LayoutManager)
{
    ui->setupUi(this);

    //connect(ui->kbHorizontal,SIGNAL(input(QString, Core::Keyboards)),ui->textWidget,SLOT(processInput(QString, Core::Keyboards)));
    connect(ui->kbVertical,SIGNAL(input(QString, Core::Keyboards)),ui->textWidget,SLOT(processInput(QString, Core::Keyboards)));
    //connect(ui->kbHorizontal,SIGNAL(inputStyleChanged(int)),ui->textWidget,SLOT(settingsChanged(int)));
    connect(ui->kbVertical,SIGNAL(inputStyleChanged(int)),ui->textWidget,SLOT(settingsChanged(int)));

    //TODO: only test purpose
    ui->kbHorizontal->hide();
}

LayoutManager::~LayoutManager()
{
    delete ui;
}

TextProcessor* LayoutManager::getTextProcessor()
{
    return ui->textWidget;
}

void LayoutManager::enableQwerty()
{
    ui->kbVertical->enableQwerty();
}

==> fastsms_0.5-6.tar.gz: fastsms-0.5/src/layoutmanager.cpp <==
/****************************************************************************
**
** Copyright (C) 2010  Aimone Davide realsportcars@hotmail.com
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
**
****************************************************************************/

#include "layoutmanager.h"
#include "ui_layoutmanager.h"
#include "keyboardmanager.h"
#include "fastsmswidget.h"


LayoutManager::LayoutManager(QWidget *parent) :
        QWidget(parent),
        ui(new Ui::LayoutManager)
{
    ui->setupUi(this);

    //connect(ui->kbHorizontal,SIGNAL(input(QString, Core::Keyboards)),ui->textWidget,SLOT(processInput(QString, Core::Keyboards)));
    connect(ui->kbVertical,SIGNAL(input(QString, Core::Keyboards)),ui->textWidget,SLOT(processInput(QString, Core::Keyboards)));
    //connect(ui->kbHorizontal,SIGNAL(inputStyleChanged(int)),ui->textWidget,SLOT(settingsChanged(int)));
    connect(ui->kbVertical,SIGNAL(inputStyleChanged(int)),ui->textWidget,SLOT(settingsChanged(int)));

    connect(ui->kbVertical,SIGNAL(inputStyleChanged(int)),qobject_cast<FastSMSWidget *> (parentWidget()),SLOT(actionMenu(int)));

    //TODO: only test purpose
    ui->kbHorizontal->hide();
}

LayoutManager::~LayoutManager()
{
    delete ui;
}

TextProcessor* LayoutManager::getTextProcessor()
{
    return ui->textWidget;
}

void LayoutManager::enableQwerty()
{
    ui->kbVertical->enableQwerty();
}

void LayoutManager::enableAlfanum()
{
    ui->kbVertical->enableAlfanum();
}
